Image.Kino (image v0.66.0)

Copy Markdown View Source

Helper functions to simplify rendering images in Kino.

Note

This module is only available if the optional dependency Kino is configured in mix.exs.

Summary

Functions

Renders an image in Kino,

Functions

show(image, opts \\ [])

(since 0.18.0)
@spec show(image :: Vix.Vips.Image.t(), options :: Keyword.t()) :: Kino.Image.t()

Renders an image in Kino,

Arguments

Options

  • :max_height determines the maximum height for the rendered image. The aspect ratio of the rendered image is unchanged. The default is 200.

Returns